distance3d
==========

Distance computation and collision detection in 3D in pure Python.

Features
--------

* Collision detection and distance computation with GJK.
* Calculation of penetration depth with EPA.
* Collision detection and calculation of penetration depth with MPR.
* Various specific distance calculations for points, lines, line segments,
  planes, triangles, rectangles, circles, disks, boxes, cylinders, ellipsoids,
  ...
* Broad phase collision detection with bounding volume hierarchy (AABB tree).
* Self-collision detection for robots.
* Contact wrench computation with hydroelastic contact model (pressure field
  model).

Content
-------

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   api
   _auto_examples/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
